.. _recipe_asr.phonopy:

asr.phonopy
===========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.phonopy`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.phonopy.calculate`
  - :py:func:`asr.phonopy.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.phonopy

or as a python module

.. code-block:: console

   $ python -m asr.phonopy

Detailed description
--------------------
Phonopy phonon band structure.

Steps
-----


asr.phonopy@calculate
^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.phonopy.calculate
   

asr.phonopy
^^^^^^^^^^^
.. autofunction:: asr.phonopy.main
   